Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-18 07:43:06 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-18 07:43:55 +0300
commitcc10d8653575e0d299b330521c98027f1dc8da36 (patch)
treee48d07b85d634119b9b1c52fe8dc480949eba7ba /source/blender/editors/space_view3d/view3d_camera_control.c
parent4719e7ec7a9c3095117bd2b0b08aeb1d72c62d98 (diff)
DNA: rename Object.size -> scale
Resolves a common cause of confusion.
Diffstat (limited to 'source/blender/editors/space_view3d/view3d_camera_control.c')
-rw-r--r--source/blender/editors/space_view3d/view3d_camera_control.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/editors/space_view3d/view3d_camera_control.c b/source/blender/editors/space_view3d/view3d_camera_control.c
index 33c2da00f97..d1ff73d1f87 100644
--- a/source/blender/editors/space_view3d/view3d_camera_control.c
+++ b/source/blender/editors/space_view3d/view3d_camera_control.c
@@ -251,21 +251,21 @@ void ED_view3d_cameracontrol_update(
}
else {
float view_mat[4][4];
- float size_mat[4][4];
- float size_back[3];
+ float scale_mat[4][4];
+ float scale_back[3];
- /* even though we handle the size matrix, this still changes over time */
- copy_v3_v3(size_back, v3d->camera->size);
+ /* even though we handle the scale matrix, this still changes over time */
+ copy_v3_v3(scale_back, v3d->camera->scale);
ED_view3d_to_m4(view_mat, rv3d->ofs, rv3d->viewquat, rv3d->dist);
- size_to_mat4(size_mat, v3d->camera->size);
- mul_m4_m4m4(view_mat, view_mat, size_mat);
+ size_to_mat4(scale_mat, v3d->camera->scale);
+ mul_m4_m4m4(view_mat, view_mat, scale_mat);
BKE_object_apply_mat4(v3d->camera, view_mat, true, true);
DEG_id_tag_update(&v3d->camera->id, ID_RECALC_TRANSFORM);
- copy_v3_v3(v3d->camera->size, size_back);
+ copy_v3_v3(v3d->camera->scale, scale_back);
id_key = &v3d->camera->id;
}